Type: Package
Package: statsExpressions
Title: Tidy Dataframes and Expressions with Statistical Details
Version: 2.0.0
Authors@R: 
    person("Indrajeet", "Patil", , "patilindrajeet.science@gmail.com", role = c("cre", "aut", "cph"),
           comment = c(ORCID = "0000-0003-1995-6531"))
Maintainer: Indrajeet Patil <patilindrajeet.science@gmail.com>
Description: Utilities for producing dataframes with rich details for the
    most common types of statistical approaches and tests: parametric,
    nonparametric, robust, and Bayesian t-test, one-way ANOVA, correlation
    analyses, contingency table analyses, and meta-analyses. The functions
    are pipe-friendly and provide a consistent syntax to work with tidy
    data. These dataframes additionally contain expressions with
    statistical details, and can be used in graphing packages. This
    package also forms the statistical processing backend for
    'ggstatsplot'. References: Patil (2021) <doi:10.21105/joss.03236>.
License: MIT + file LICENSE
URL: https://www.indrapatil.com/statsExpressions/,
        https://github.com/IndrajeetPatil/statsExpressions
BugReports: https://github.com/IndrajeetPatil/statsExpressions/issues
Depends: R (>= 4.3.0), stats
Imports: afex (>= 1.5-1), BayesFactor (>= 0.9.12-4.8), bayestestR (>=
        0.17.0), correlation (>= 0.8.8), datawizard (>= 1.3.0), dplyr
        (>= 1.2.1), effectsize (>= 1.0.2), glue (>= 1.8.1), insight (>=
        1.5.0), parameters (>= 0.28.3), performance (>= 0.16.0),
        PMCMRplus (>= 1.9.12), purrr (>= 1.2.2), rlang (>= 1.2.0),
        rstantools (>= 2.6.0), tidyr (>= 1.3.2), withr (>= 3.0.2), WRS2
        (>= 1.1-7)
Suggests: ggplot2, knitr, metaBMA, metafor, metaplus (>= 1.0-6),
        patrick, rmarkdown, survival, testthat (>= 3.3.2), utils
VignetteBuilder: knitr
Config/Needs/check: anthonynorth/roxyglobals
Config/roxyglobals/unique: TRUE
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-22 21:32:04 UTC; runner
Author: Indrajeet Patil [cre, aut, cph] (ORCID:
    <https://orcid.org/0000-0003-1995-6531>)
Repository: CRAN
Date/Publication: 2026-04-23 12:50:02 UTC
Built: R 4.6.0; ; 2026-05-01 01:11:31 UTC; unix
