# Generated by roxygen2: do not edit by hand

S3method(print,statsExpressions)
export(add_expression_col)
export(centrality_description)
export(contingency_table)
export(corr_test)
export(extract_stats_type)
export(long_to_wide_converter)
export(meta_analysis)
export(one_sample_test)
export(oneway_anova)
export(pairwise_comparisons)
export(pairwise_contingency_table)
export(stats_type_switch)
export(tidy_model_expressions)
export(tidy_model_parameters)
export(two_sample_test)
import(dplyr)
import(effectsize)
import(glue)
import(rlang)
importFrom(bayestestR,describe_posterior)
importFrom(insight,check_if_installed)
importFrom(insight,format_value)
importFrom(insight,standardize_names)
importFrom(parameters,model_parameters)
importFrom(purrr,map2)
importFrom(purrr,map_dbl)
importFrom(purrr,map_dfr)
importFrom(rstantools,bayes_R2)
