#' \code{statsExpressions}
#'
#' @title statsExpressions: Tidy Dataframes and Expressions with Statistical Details
#'
#' @description
#'
#' ```{r child="man/rmd-fragments/statsExpressions-package.Rmd"}
#'
#' ```
#'
#' @docType package
#' @aliases statsExpressions statsExpressions-package
#' @name statsExpressions-package
#' @keywords internal
"_PACKAGE"


## statsExpressions namespace: start
##
#' @import rlang
#' @import dplyr
#' @import glue
#' @import effectsize
#'
#' @importFrom insight format_value check_if_installed standardize_names
#' @importFrom parameters model_parameters
#' @importFrom bayestestR describe_posterior
#' @importFrom purrr map2 map_dbl map_dfr
#' @importFrom rstantools bayes_R2
#'
## statsExpressions namespace: end
NULL
