knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  warning = FALSE,
  message = FALSE,
  out.width = "100%",
  dpi = 300
)

# needed libraries
library(dplyr)
library(statsExpressions)

options(lifecycle_verbosity = "warning")

# for reproducibility
set.seed(123)
