# Generated by roxyglobals: do not edit by hand

utils::globalVariables(c(
  # <contingency_table>
  # <pairwise_contingency_table>
  ".counts",
  # <long_to_wide_converter>
  # <oneway_anova>
  # <pairwise_comparisons>
  ".rowid",
  # <add_expression_col>
  "df",
  # <centrality_description>
  "estimate",
  # <pairwise_comparisons>
  # <pairwise_contingency_table>
  "group1",
  # <pairwise_comparisons>
  # <pairwise_contingency_table>
  "group2",
  # <add_expression_col>
  "method",
  # <add_expression_col>
  # <centrality_description>
  "n.obs",
  # <add_expression_col>
  # <pairwise_contingency_table>
  "p.value",
  # <pairwise_comparisons>
  # <pairwise_contingency_table>
  "p.value.adj",
  # <tidy_model_parameters>
  "r.squared",
  # <pairwise_comparisons>
  # <tidy_model_expressions>
  "term",
  NULL
))
