**Hypothesis testing** and **Effect size estimation**

| Type       | Test                                             | Effect size | CI available? | Function used            |
| :--------- | :----------------------------------------------- | :---------- | :------------ | :----------------------- |
| Parametric | Meta-analysis via random-effects models          | *beta*      | Yes           | `metafor::rma()`         |
| Robust     | Meta-analysis via robust random-effects models   | *beta*      | Yes           | `metaplus::metaplus()`   |
| Bayesian   | Meta-analysis via Bayesian random-effects models | *beta*      | Yes           | `metaBMA::meta_random()` |
