| Type           | Measure      | Function used                         |
| :------------- | :----------- | :------------------------------------ |
| Parametric     | mean         | `datawizard::describe_distribution()` |
| Non-parametric | median       | `datawizard::describe_distribution()` |
| Robust         | trimmed mean | `datawizard::describe_distribution()` |
| Bayesian       | MAP          | `datawizard::describe_distribution()` |
