
**Hypothesis testing**

| Type           | Test                                     | Function used            |
| :------------- | :--------------------------------------- | :----------------------- |
| Parametric     | One-sample Student's *t*-test            | `stats::t.test()`        |
| Non-parametric | One-sample Wilcoxon test                 | `stats::wilcox.test()`   |
| Robust         | Bootstrap-*t* method for one-sample test | `WRS2::trimcibt()`       |
| Bayesian       | One-sample Student's *t*-test            | `BayesFactor::ttestBF()` |

**Effect size estimation**

| Type           | Effect size                     | CI available? | Function used                                      |
| :------------- | :------------------------------ | :------------ | :------------------------------------------------- |
| Parametric     | Cohen's *d*, Hedge's *g*        | Yes           | `effectsize::cohens_d()`, `effectsize::hedges_g()` |
| Non-parametric | *r* (rank-biserial correlation) | Yes           | `effectsize::rank_biserial()`                      |
| Robust         | trimmed mean                    | Yes           | `WRS2::trimcibt()`                                 |
| Bayesian       | difference                      | Yes           | `bayestestR::describe_posterior()`                 |
