**Hypothesis testing** and **Effect size estimation**

| Type           | Test                                         | CI available? | Function used                |
| :------------- | :------------------------------------------- | :------------ | :--------------------------- |
| Parametric     | Pearson's correlation coefficient            | Yes           | `correlation::correlation()` |
| Non-parametric | Spearman's rank correlation coefficient      | Yes           | `correlation::correlation()` |
| Robust         | Winsorized Pearson's correlation coefficient | Yes           | `correlation::correlation()` |
| Bayesian       | Bayesian Pearson's correlation coefficient   | Yes           | `correlation::correlation()` |
