#### between-subjects

**Hypothesis testing**

| Type           | No. of groups | Test                                            | Function used            |
| :------------- | :------------ | :---------------------------------------------- | :----------------------- |
| Parametric     | > 2           | Fisher's or Welch's one-way ANOVA               | `stats::oneway.test()`   |
| Non-parametric | > 2           | Kruskal-Wallis one-way ANOVA                    | `stats::kruskal.test()`  |
| Robust         | > 2           | Heteroscedastic one-way ANOVA for trimmed means | `WRS2::t1way()`          |
| Bayesian       | > 2           | Fisher's ANOVA                                  | `BayesFactor::anovaBF()` |

**Effect size estimation**

| Type           | No. of groups | Effect size                                | CI available? | Function used                                              |
| :------------- | :------------ | :----------------------------------------- | :------------ | :--------------------------------------------------------- |
| Parametric     | > 2           | partial eta-squared, partial omega-squared | Yes           | `effectsize::omega_squared()`, `effectsize::eta_squared()` |
| Non-parametric | > 2           | rank epsilon squared                       | Yes           | `effectsize::rank_epsilon_squared()`                       |
| Robust         | > 2           | Explanatory measure of effect size         | Yes           | `WRS2::t1way()`                                            |
| Bayesian       | > 2           | Bayesian R-squared                         | Yes           | `performance::r2_bayes()`                                  |

#### within-subjects

**Data requirement**: Repeated measures tests assume a *complete* design with
exactly **one observation per subject per condition**. If your data has multiple
trials per cell, aggregate first (e.g., take the mean). Verify with
`table(data$subject, data$condition)` — every cell should equal `1`.

**Hypothesis testing**

| Type           | No. of groups | Test                                                              | Function used            |
| :------------- | :------------ | :---------------------------------------------------------------- | :----------------------- |
| Parametric     | > 2           | One-way repeated measures ANOVA                                   | `afex::aov_ez()`         |
| Non-parametric | > 2           | Friedman rank sum test                                            | `stats::friedman.test()` |
| Robust         | > 2           | Heteroscedastic one-way repeated measures ANOVA for trimmed means | `WRS2::rmanova()`        |
| Bayesian       | > 2           | One-way repeated measures ANOVA                                   | `BayesFactor::anovaBF()` |

**Effect size estimation**

| Type           | No. of groups | Effect size                                                     | CI available? | Function used                                              |
| :------------- | :------------ | :-------------------------------------------------------------- | :------------ | :--------------------------------------------------------- |
| Parametric     | > 2           | partial eta-squared, partial omega-squared                      | Yes           | `effectsize::omega_squared()`, `effectsize::eta_squared()` |
| Non-parametric | > 2           | Kendall's coefficient of concordance                            | Yes           | `effectsize::kendalls_w()`                                 |
| Robust         | > 2           | Algina-Keselman-Penfield robust standardized difference average | Yes           | `WRS2::wmcpAKP()`                                          |
| Bayesian       | > 2           | Bayesian R-squared                                              | Yes           | `performance::r2_bayes()`                                  |
