**Summary of available analyses**

| Test                       | Function                 |
| :------------------------- | :----------------------- |
| one-sample *t*-test        | `one_sample_test()`      |
| two-sample *t*-test        | `two_sample_test()`      |
| one-way ANOVA              | `oneway_anova()`         |
| correlation analysis       | `corr_test()`            |
| contingency table analysis | `contingency_table()`    |
| meta-analysis              | `meta_analysis()`        |
| pairwise comparisons       | `pairwise_comparisons()` |
| pairwise contingency table | `pairwise_contingency_table()` |

**Summary of details available for analyses**

| Analysis                        | Hypothesis testing | Effect size estimation |
| :------------------------------ | :----------------- | :--------------------- |
| (one/two-sample) *t*-test       | ✅                 | ✅                     |
| one-way ANOVA                   | ✅                 | ✅                     |
| correlation                     | ✅                 | ✅                     |
| (one/two-way) contingency table | ✅                 | ✅                     |
| random-effects meta-analysis    | ✅                 | ✅                     |

**Summary of supported statistical approaches**

| Description                                       | Parametric | Non-parametric | Robust | Bayesian |
| :------------------------------------------------ | :--------- | :------------- | :----- | :------- |
| Between group/condition comparisons               | ✅         | ✅             | ✅     | ✅       |
| Within group/condition comparisons                | ✅         | ✅             | ✅     | ✅       |
| Distribution of a numeric variable                | ✅         | ✅             | ✅     | ✅       |
| Correlation between two variables                 | ✅         | ✅             | ✅     | ✅       |
| Association between categorical variables         | ✅         | ✅             | ❌     | ✅       |
| Equal proportions for categorical variable levels | ✅         | ✅             | ❌     | ✅       |
| Random-effects meta-analysis                      | ✅         | ❌             | ✅     | ✅       |
